@@ -1,4 +1,4 @@
-# Copyright (c) Microsoft Corporation. All rights reserved.
+# Copyright (c) Microsoft Corporation and Fairlearn contributors.
 # Licensed under the MIT License.
 
 import logging
@@ -10,6 +10,7 @@ from sklearn.utils.validation import check_X_y, check_consistent_length, check_a
 logger = logging.getLogger(__file__)
 
 _KW_SENSITIVE_FEATURES = "sensitive_features"
+_KW_CONTROL_FEATURES = "control_features"
 
 _MESSAGE_X_NONE = "Must supply X"
 _MESSAGE_Y_NONE = "Must supply y"
@@ -18,7 +19,7 @@ _MESSAGE_X_Y_ROWS = "X and y must have same number of rows"
 _MESSAGE_X_SENSITIVE_ROWS = "X and the sensitive features must have same number of rows"
 _MESSAGE_RATIO_NOT_IN_RANGE = "ratio must lie between (0,1]"
 _INPUT_DATA_FORMAT_ERROR_MESSAGE = "The only allowed input data formats for {} are: {}. " \
-                                     "Your provided data was of type {}."
+    "Your provided data was of type {}."
 _EMPTY_INPUT_ERROR_MESSAGE = "At least one of sensitive_features, labels, or scores are empty."
 _LABELS_NOT_0_1_ERROR_MESSAGE = "Supplied y labels are not 0 or 1"
 _MORE_THAN_ONE_COLUMN_ERROR_MESSAGE = "{} is a {} with more than one column"
@@ -30,33 +31,42 @@ _ALLOWED_INPUT_TYPES_X = [np.ndarray, pd.DataFrame]
 _ALLOWED_INPUT_TYPES_SENSITIVE_FEATURES = [np.ndarray, pd.DataFrame, pd.Series, list]
 _ALLOWED_INPUT_TYPES_Y = [np.ndarray, pd.DataFrame, pd.Series, list]
 
-_SENSITIVE_FEATURE_COMPRESSION_SEPARATOR = ","
+_MERGE_COLUMN_SEPARATOR = ","
 
 
 def _validate_and_reformat_input(X, y=None, expect_y=True, enforce_binary_labels=False, **kwargs):
     """Validate input data and return the data in an appropriate format.
 
-    :param X: The feature matrix
-    :type X: numpy.ndarray or pandas.DataFrame
-    :param y: The label vector
-    :type y: numpy.ndarray, pandas.DataFrame, pandas.Series, or list
-    :param expect_y: if True y needs to be provided, otherwise ignores the argument; default True
-    :type expect_y: bool
-    :param enforce_binary_labels: if True raise exception if there are more than two distinct
+    The :code:`**kwargs` can contain :code:`sensitive_features=` and :code:`control_features=`
+    parameters.
+
+    Parameters
+    ----------
+    X : numpy.ndarray, pandas.DataFrame
+        The feature matrix
+    y : numpy.ndarray, pandas.DataFrame, pandas.Series, or list
+        The label vector
+    expect_y : bool
+        If True y needs to be provided, otherwise ignores the argument; default True
+    enforce_binary_labels : bool
+        If True raise exception if there are more than two distinct
         values in the `y` data; default False
-    :type enforce_binary_labels: bool
-    :return: the validated and reformatted X, y, and sensitive_features; note that certain
-        estimators rely on metadata encoded in X which may be stripped during the reformatting
-        process, so mitigation methods should ideally use the input X instead of the returned X
-        for training estimators and leave potential reformatting of X to the estimator.
-    :rtype: (pandas.DataFrame, pandas.Series, pandas.Series)
+
+    Returns
+    -------
+    Tuple(pandas.DataFrame, pandas.Series, pandas.Series, pandas.Series)
+        The validated and reformatted X, y, sensitive_features and control_features; note
+        that certain estimators rely on metadata encoded in X which may be stripped during
+        the reformatting process, so mitigation methods should ideally use the input X instead
+        of the returned X for training estimators and leave potential reformatting of X to the
+        estimator.
     """
     if y is not None:
         # calling check_X_y with a 2-dimensional y causes a warning, so ensure it is 1-dimensional
         if isinstance(y, np.ndarray) and len(y.shape) == 2 and y.shape[1] == 1:
-            y = y.squeeze()
+            y = y.reshape(-1)
         elif isinstance(y, pd.DataFrame) and y.shape[1] == 1:
-            y = y.to_numpy().squeeze()
+            y = y.to_numpy().reshape(-1)
 
         X, y = check_X_y(X, y)
         y = check_array(y, ensure_2d=False, dtype='numeric')
@@ -76,8 +86,19 @@ def _validate_and_reformat_input(X, y=None, expect_y=True, enforce_binary_labels
 
     # compress multiple sensitive features into a single column
     if len(sensitive_features.shape) > 1 and sensitive_features.shape[1] > 1:
-        sensitive_features = \
-            _compress_multiple_sensitive_features_into_single_column(sensitive_features)
+        sensitive_features = _merge_columns(sensitive_features)
+
+    # Handle the control features
+    control_features = kwargs.get(_KW_CONTROL_FEATURES)
+    if control_features is not None:
+        check_consistent_length(X, control_features)
+        control_features = check_array(control_features, ensure_2d=False, dtype=None)
+
+        # compress multiple control features into a single column
+        if len(control_features.shape) > 1 and control_features.shape[1] > 1:
+            control_features = _merge_columns(control_features)
+
+        control_features = pd.Series(control_features.squeeze())
 
     # If we don't have a y, then need to fiddle with return type to
     # avoid a warning from pandas
@@ -86,28 +107,37 @@ def _validate_and_reformat_input(X, y=None, expect_y=True, enforce_binary_labels
     else:
         result_y = pd.Series(dtype="float64")
 
-    return pd.DataFrame(X), result_y, pd.Series(sensitive_features.squeeze())
+    return pd.DataFrame(X), result_y, pd.Series(sensitive_features.squeeze()), control_features
 
 
-def _compress_multiple_sensitive_features_into_single_column(sensitive_features):
-    """Compress multiple sensitive features into a single column.
+def _merge_columns(feature_columns: np.ndarray) -> np.ndarray:
+    """Merge multiple columns into a single new column.
 
-    The resulting mapping converts multiple dimensions into the Cartesian product of the
-    individual columns.
+    Compresses multiple columns into a single column by concatenating the
+    stringified values. For example, given two columns
+    :code:`['A', 'A', 'B', 'B']` and :code:`[4, 5, 4, 5]` the resultant
+    column will be
+    :code:`['A,4', 'A,5', 'B,4', 'B,5']`.
 
-    :param sensitive_features: multi-dimensional array of sensitive features
-    :type sensitive_features: `numpy.ndarray`
-    :return: one-dimensional array of mapped sensitive features
+    Parameters
+    ----------
+    feature_column : numpy.ndarray
+        Multi-dimensional array of columns to be merged
+
+    Returns
+    -------
+    numpy.ndarray
+        One-dimensional array of merged columns
     """
-    if not isinstance(sensitive_features, np.ndarray):
+    if not isinstance(feature_columns, np.ndarray):
         raise ValueError("Received argument of type {} instead of expected numpy.ndarray"
-                         .format(type(sensitive_features).__name__))
+                         .format(type(feature_columns).__name__))
     return np.apply_along_axis(
-        lambda row: _SENSITIVE_FEATURE_COMPRESSION_SEPARATOR.join(
+        lambda row: _MERGE_COLUMN_SEPARATOR.join(
             [str(row[i])
                 .replace("\\", "\\\\")  # escape backslash and separator
-                .replace(_SENSITIVE_FEATURE_COMPRESSION_SEPARATOR,
-                         "\\" + _SENSITIVE_FEATURE_COMPRESSION_SEPARATOR)
+                .replace(_MERGE_COLUMN_SEPARATOR,
+                         "\\" + _MERGE_COLUMN_SEPARATOR)
                 for i in range(len(row))]),
         axis=1,
-        arr=sensitive_features)
+        arr=feature_columns)
