@@ -1,4 +1,4 @@
-# Copyright (c) Microsoft Corporation. All rights reserved.
+# Copyright (c) Microsoft Corporation and Fairlearn contributors.
 # Licensed under the MIT License.
 
 _PRECISION = 1e-8
@@ -18,9 +18,4 @@ _SHRINK_REGRET = 0.8
 _SHRINK_ETA = 0.8
 
 # The smallest number of iterations after which ExponentiatedGradient terminates.
-_MIN_T = 5
-
-# If _RUN_LP_STEP is set to True, then each step of exponentiated
-# gradient is followed by the saddle point optimization over the convex
-# hull of classifiers returned so far.
-_RUN_LP_STEP = True
+_MIN_ITER = 5
