@@ -1,4 +1,4 @@
-# Copyright (c) Microsoft Corporation. All rights reserved.
+# Copyright (c) Microsoft Corporation and Fairlearn contributors.
 # Licensed under the MIT License.
 
 """Holds the various Moments."""
@@ -6,23 +6,25 @@
 from .moment import Moment  # noqa: F401
 from .moment import ClassificationMoment, LossMoment  # noq: F401
 
-from .conditional_selection_rate import ConditionalSelectionRate  # noqa: F401
-from .conditional_selection_rate import DemographicParity, EqualizedOdds, TruePositiveRateDifference, ErrorRateRatio  # noqa: F401,E501
+from .utility_parity import UtilityParity  # noqa: F401
+from .utility_parity import DemographicParity, EqualizedOdds, \
+    TruePositiveRateParity, FalsePositiveRateParity, ErrorRateParity  # noqa: F401
 from .error_rate import ErrorRate   # noqa: F401
-from .bounded_group_loss import GroupLossMoment   # noqa: F401
+from .bounded_group_loss import BoundedGroupLoss   # noqa: F401
 from .bounded_group_loss import SquareLoss, AbsoluteLoss, ZeroOneLoss  # noqa: F401
 
 __all__ = [
     "AbsoluteLoss",
     "Moment",
     "ClassificationMoment",
-    "ConditionalSelectionRate",
+    "UtilityParity",
     "DemographicParity",
     "EqualizedOdds",
-    "TruePositiveRateDifference",
-    "ErrorRateRatio",
+    "TruePositiveRateParity",
+    "FalsePositiveRateParity",
+    "ErrorRateParity",
     "ErrorRate",
-    "GroupLossMoment",
+    "BoundedGroupLoss",
     "LossMoment",
     "SquareLoss",
     "ZeroOneLoss"
