@@ -1,51 +1,41 @@
-# Copyright (c) Microsoft Corporation. All rights reserved.
+# Copyright (c) Microsoft Corporation and Fairlearn contributors.
 # Licensed under the MIT License.
 
-"""Defines the fairlearn dashboard class."""
+"""Defines the Fairlearn dashboard class."""
 
 from ._fairlearn_widget import FairlearnWidget
-from fairlearn.metrics import (
-    true_negative_rate_group_summary,
-    false_positive_rate_group_summary,
-    false_negative_rate_group_summary,
-    _root_mean_squared_error_group_summary,
-    _balanced_root_mean_squared_error_group_summary,
-    mean_prediction_group_summary,
-    selection_rate_group_summary,
-    _mean_overprediction_group_summary,
-    _mean_underprediction_group_summary,
+from fairlearn.metrics._extra_metrics import (
+    _balanced_root_mean_squared_error, _mean_overprediction,
+    _mean_underprediction, _root_mean_squared_error, false_negative_rate,
+    false_positive_rate, mean_prediction, selection_rate, true_negative_rate)
+from fairlearn.metrics import MetricFrame
+from warnings import warn
 
-    accuracy_score_group_summary,
-    precision_score_group_summary,
-    recall_score_group_summary,
-    roc_auc_score_group_summary,
-    zero_one_loss_group_summary,
-    mean_absolute_error_group_summary,
-    mean_squared_error_group_summary,
-    r2_score_group_summary,
-    )
 
 from IPython.display import display
 from scipy.sparse import issparse
+import sklearn.metrics as skm
 import copy
 import numpy as np
 import pandas as pd
 
 
 class FairlearnDashboard(object):
-    """The dashboard class, wraps the dashboard component.
+    r"""The dashboard class, wraps the dashboard component.
 
-    :param sensitive_features:  A matrix of feature vector examples (# examples x # features),
+    Parameters
+    ----------
+    sensitive_features : numpy.ndarray, list[][], pandas.DataFrame, pandas.Series
+        A matrix of feature vector examples (# examples x # features),
         these can be from the initial dataset, or reserved from training.
-    :type sensitive_features: numpy.array or list[][] or pandas.DataFrame or pandas.Series
-    :param y_true: The true labels or values for the provided dataset.
-    :type y_true: numpy.array or list[]
-    :param y_pred: Array of output predictions from models to be evaluated. Can be a single
+    y_true : numpy.ndarray, list[]
+        The true labels or values for the provided dataset.
+    y_pred : numpy.ndarray, list[][], list[], dict {string: list[]}
+        Array of output predictions from models to be evaluated. Can be a single
         array of predictions, or a 2D list over multiple models. Can be a dictionary
         of named model predictions.
-    :type y_pred: numpy.array or list[][] or list[] or dict {string: list[]}
-    :param sensitive_feature_names: Feature names
-    :type sensitive_feature_names: numpy.array or list[]
+    sensitive_feature_names : numpy.ndarray, list[]
+        Feature names
     """
 
     def __init__(
@@ -53,7 +43,12 @@ class FairlearnDashboard(object):
             sensitive_features,
             y_true, y_pred,
             sensitive_feature_names=None):
-        """Initialize the fairlearn Dashboard."""
+        """Initialize the Fairlearn Dashboard."""
+        warn("The FairlearnDashboard will move from Fairlearn to the "
+             "raiwidgets package after the v0.5.0 release. Instead, Fairlearn "
+             "will provide some of the existing functionality through "
+             "matplotlib-based visualizations.")
+
         self._widget_instance = FairlearnWidget()
         if sensitive_features is None or y_true is None or y_pred is None:
             raise ValueError("Required parameters not provided")
@@ -63,83 +58,91 @@ class FairlearnDashboard(object):
         self._metric_methods = {
             "accuracy_score": {
                 "model_type": ["classification"],
-                "function": accuracy_score_group_summary
+                "function": skm.accuracy_score
             },
             "balanced_accuracy_score": {
                 "model_type": ["classification"],
-                "function": roc_auc_score_group_summary
+                "function": skm.roc_auc_score
             },
             "precision_score": {
                 "model_type": ["classification"],
-                "function": precision_score_group_summary
+                "function": skm.precision_score
             },
             "recall_score": {
                 "model_type": ["classification"],
-                "function": recall_score_group_summary
+                "function": skm.recall_score
             },
             "zero_one_loss": {
                 "model_type": [],
-                "function": zero_one_loss_group_summary
+                "function": skm.zero_one_loss
             },
             "specificity_score": {
                 "model_type": [],
-                "function": true_negative_rate_group_summary
+                "function": true_negative_rate
             },
             "miss_rate": {
                 "model_type": [],
-                "function": false_negative_rate_group_summary
+                "function": false_negative_rate
             },
             "fallout_rate": {
                 "model_type": [],
-                "function": false_positive_rate_group_summary
+                "function": false_positive_rate
             },
             "false_positive_over_total": {
                 "model_type": [],
-                "function": false_positive_rate_group_summary
+                "function": false_positive_rate
             },
             "false_negative_over_total": {
                 "model_type": [],
-                "function": false_negative_rate_group_summary
+                "function": false_negative_rate
             },
             "selection_rate": {
                 "model_type": [],
-                "function": selection_rate_group_summary
+                "function": selection_rate
             },
             "auc": {
                 "model_type": ["probability"],
-                "function": roc_auc_score_group_summary
+                "function": skm.roc_auc_score
             },
             "root_mean_squared_error": {
                 "model_type": ["regression", "probability"],
-                "function": _root_mean_squared_error_group_summary
+                "function": _root_mean_squared_error
             },
             "balanced_root_mean_squared_error": {
                 "model_type": ["probability"],
-                "function": _balanced_root_mean_squared_error_group_summary
+                "function": _balanced_root_mean_squared_error
             },
             "mean_squared_error": {
                 "model_type": ["regression", "probability"],
-                "function": mean_squared_error_group_summary
+                "function": skm.mean_squared_error
             },
             "mean_absolute_error": {
                 "model_type": ["regression", "probability"],
-                "function": mean_absolute_error_group_summary
+                "function": skm.mean_absolute_error
             },
             "r2_score": {
                 "model_type": ["regression"],
-                "function": r2_score_group_summary
+                "function": skm.r2_score
+            },
+            "f1_score": {
+                "model_type": ["classification"],
+                "function": skm.f1_score
+            },
+            "log_loss": {
+                "model_type": ["probability"],
+                "function": skm.log_loss
             },
             "overprediction": {
                 "model_type": [],
-                "function": _mean_overprediction_group_summary
+                "function": _mean_overprediction
             },
             "underprediction": {
                 "model_type": [],
-                "function": _mean_underprediction_group_summary
+                "function": _mean_underprediction
             },
             "average": {
                 "model_type": [],
-                "function": mean_prediction_group_summary
+                "function": mean_prediction
             }
         }
 
@@ -162,6 +165,7 @@ class FairlearnDashboard(object):
             self._y_pred = self._convert_to_list(y_pred)
         if len(np.shape(self._y_pred)) == 1:
             self._y_pred = [self._y_pred]
+
         self._y_true = self._convert_to_list(y_true)
 
         if np.shape(self._y_true)[0] != np.shape(self._y_pred)[1]:
@@ -200,22 +204,22 @@ class FairlearnDashboard(object):
                     if id not in response:
                         data = new[id]
                         method = self._metric_methods.get(data["metricKey"]).get("function")
-                        binVector = data["binVector"]
-                        prediction = method(
-                            self._y_true,
-                            self._y_pred[data["modelIndex"]],
-                            sensitive_features=binVector)
+                        prediction = MetricFrame(method,
+                                                 self._y_true,
+                                                 self._y_pred[data["modelIndex"]],
+                                                 sensitive_features=data["binVector"])
                         response[id] = {
-                                "global": prediction.overall,
-                                "bins": prediction.by_group
-                                }
-                except Exception as ed:
+                            "global": prediction.overall,
+                            "bins": prediction.by_group.to_dict()
+                        }
+                except Exception as ed:  # noqa: B902
                     response[id] = {
                         "error": ed,
                         "global": 0,
                         "bins": []}
             self._widget_instance.response = response
-        except Exception:
+        except Exception:  # noqa: B902
+            # Not sure why we're masking the exception here
             raise ValueError("Error while making request")
 
     def _show(self):
